@@ -926,7 +926,7 @@ FMT_FUNC void format_system_error(
   format_error_code(out, error_code, message);
 }
 
-FMT_FUNC void internal::error_handler::on_error(const char *message) {
+[[noreturn]] FMT_FUNC void internal::error_handler::on_error(const char *message) {
   FMT_THROW(format_error(message));
 }
 
