@@ -671,8 +671,8 @@ namespace libsemigroups {
       void make_deductions_dfs(coset_type const);
       void process_deductions();
 
-      inline coset_type tau(coset_type const c, letter_type const a) const
-          noexcept {
+      inline coset_type tau(coset_type const  c,
+                            letter_type const a) const noexcept {
         LIBSEMIGROUPS_ASSERT(is_valid_coset(c));
         LIBSEMIGROUPS_ASSERT(a < _table.nr_cols());
         return _table.get(c, a);
@@ -712,8 +712,8 @@ namespace libsemigroups {
                                word_type const&  v) noexcept {
         REPORT_VERBOSE_DEFAULT("pushing coset %d through %s = %s\n",
                                c,
-                               detail::to_string(u),
-                               detail::to_string(v));
+                               detail::to_string(u).c_str(),
+                               detail::to_string(v).c_str());
 
         LIBSEMIGROUPS_ASSERT(is_active_coset(c));
         LIBSEMIGROUPS_ASSERT(!u.empty());
@@ -754,8 +754,8 @@ namespace libsemigroups {
                                   word_type const&  v) noexcept {
         REPORT_VERBOSE_DEFAULT("pushing coset %d through %s = %s\n",
                                c,
-                               detail::to_string(u),
-                               detail::to_string(v));
+                               detail::to_string(u).c_str(),
+                               detail::to_string(v).c_str());
         LIBSEMIGROUPS_ASSERT(is_active_coset(c));
         LIBSEMIGROUPS_ASSERT(!u.empty());
         LIBSEMIGROUPS_ASSERT(!v.empty());
